@@ -36,6 +36,7 @@
 
 // Qt
 #include <qsocketnotifier.h>
+#include <qregularexpression.h>
 
 // #define if you want MUCH debugging output
 //#define ALSA_SWITCH_DEBUG
@@ -57,9 +58,9 @@ ALSA_getMixer(Mixer *mixer, int device )
 
 Mixer_ALSA::Mixer_ALSA( Mixer* mixer, int device ) : MixerBackend(mixer,  device )
 {
-    m_fds = 0;
-    _handle = 0;
-    ctl_handle = 0;
+    m_fds = nullptr;
+    _handle = nullptr;
+    ctl_handle = nullptr;
     _initialUpdate = true;
 }
 
@@ -155,9 +156,9 @@ int Mixer_ALSA::open()
 
         /* ------------------------------------------------------------------------------- */
 
-        Volume* volPlay    = 0;
-        Volume* volCapture = 0;
-        QList<QString*> enumList;
+        Volume *volPlay = nullptr;
+        Volume *volCapture = nullptr;
+        QList<QString *> enumList;
 
         if ( snd_mixer_selem_is_enumerated(elem) ) {
             // --- Enumerated ---
@@ -202,12 +203,12 @@ int Mixer_ALSA::open()
         // TODO: this does not appear to work with volume feedback
         //mdNew->setHardwareId("hw:"+QByteArray::number(m_devnum)+","+QByteArray::number(idx));
 
-        if ( volPlay    != 0      )
+        if (volPlay!=nullptr)
         {
         	mdNew->addPlaybackVolume(*volPlay);
             delete volPlay;
         }
-        if ( volCapture != 0      )
+        if (volCapture!=nullptr)
         {
         	mdNew->addCaptureVolume (*volCapture);
             delete volCapture;
@@ -220,7 +221,7 @@ int Mixer_ALSA::open()
 
        	shared_ptr<MixDevice> md = mdNew->addToPool();
         m_mixDevices.append( md );
-         
+
 
         // --- Recommended master ----------------------------------------
         if ( md->playbackVolume().hasVolume() )
@@ -320,7 +321,7 @@ int Mixer_ALSA::openAlsaDevice(const QString& devName)
                 warnOnce = false;
     		qCDebug(KMIX_LOG) << probeMessage << "not found: snd_mixer_open err=" << snd_strerror(err);
     	}
-        _handle = 0;
+        _handle = nullptr;
         return Mixer::ERR_OPEN; // if we cannot open the mixer, we have no devices
     }
 
@@ -334,7 +335,7 @@ int Mixer_ALSA::openAlsaDevice(const QString& devName)
         return Mixer::ERR_OPEN;
     }
 
-    if ( ( err = snd_mixer_selem_register ( _handle, NULL, NULL ) ) < 0 )
+    if ( ( err = snd_mixer_selem_register ( _handle, nullptr, nullptr ) ) < 0 )
     {
         if (warnOnce)
     	{
@@ -369,7 +370,6 @@ int Mixer_ALSA::openAlsaDevice(const QString& devName)
 int Mixer_ALSA::setupAlsaPolling()
 {
 	// --- Step 1: Retrieve FD's from ALSALIB
-	int err;
 	int countNew = 0;
 	if ((countNew = snd_mixer_poll_descriptors_count(_handle)) < 0) {
 		qCDebug(KMIX_LOG) << "Mixer_ALSA::poll() , snd_mixer_poll_descriptors_count() err=" <<  countNew << "\n";
@@ -391,6 +391,8 @@ int Mixer_ALSA::setupAlsaPolling()
 	 */
 	if (true)
 	{
+		int err;
+
 		// As documentation purpose, please keep the "if (true)" and the comment above explaining it.
 		 while (!m_sns.isEmpty())
 		     delete m_sns.takeFirst();
@@ -398,7 +400,7 @@ int Mixer_ALSA::setupAlsaPolling()
 
 		free(m_fds);
 		m_fds = static_cast<struct pollfd *>(calloc(countNew, sizeof(struct pollfd)));
-		if (m_fds == NULL) {
+		if (m_fds == nullptr) {
 			qCDebug(KMIX_LOG) << "Mixer_ALSA::poll() , calloc() = null" << "\n";
 			return Mixer::ERR_OPEN;
 		}
@@ -417,13 +419,14 @@ int Mixer_ALSA::setupAlsaPolling()
 		// --- Step 2: Create QSocketNotifier's for the FD's
 		for ( int i = 0; i < countNew; ++i )
 		{
-			QSocketNotifier* qsn = new QSocketNotifier(m_fds[i].fd, QSocketNotifier::Read);
+                        // TODO: memory leak, not parented and never deleted
+			QSocketNotifier *qsn = new QSocketNotifier(m_fds[i].fd, QSocketNotifier::Read);
 			m_sns.append(qsn);
-			connect(qsn, SIGNAL(activated(int)), SLOT(readSetFromHW()), Qt::QueuedConnection);
+			connect(qsn, &QSocketNotifier::activated, this, &Mixer_ALSA::readSetFromHW, Qt::QueuedConnection);
 		}
 	}
 
-	return 0;
+	return (Mixer::OK);
 }
 
 void Mixer_ALSA::addEnumerated(snd_mixer_elem_t *elem, QList<QString*>& enumList)
@@ -450,7 +453,7 @@ void Mixer_ALSA::addEnumerated(snd_mixer_elem_t *elem, QList<QString*>& enumList
 
 Volume* Mixer_ALSA::addVolume(snd_mixer_elem_t *elem, bool capture)
 {
-    Volume* vol = 0;
+    Volume *vol = nullptr;
     long maxVolume = 0, minVolume = 0;
 
     // Add volumes
@@ -474,7 +477,7 @@ Volume* Mixer_ALSA::addVolume(snd_mixer_elem_t *elem, bool capture)
     if ( hasVolume || hasSwitch ) {
         //qCDebug(KMIX_LOG) << "Add somthing with chn=" << chn << ", capture=" << capture;
         vol = new Volume( maxVolume, minVolume, hasSwitch, capture);
-	
+
 	    // Add volumes
       if ( !capture && snd_mixer_selem_has_playback_volume(elem) ) {
 	  if ( snd_mixer_selem_has_playback_channel(elem,SND_MIXER_SCHN_FRONT_LEFT  )) vol->addVolumeChannel(VolumeChannel(Volume::LEFT));
@@ -508,7 +511,7 @@ void Mixer_ALSA::deinitAlsaPolling()
 {
 	if ( m_fds )
 		free( m_fds );
-	m_fds = 0;
+	m_fds = nullptr;
 
 	while (!m_sns.isEmpty())
 		delete m_sns.takeFirst();
@@ -522,13 +525,13 @@ Mixer_ALSA::close()
   int ret=0;
   m_isOpen = false;
 
-  if ( ctl_handle != 0)
+  if (ctl_handle !=nullptr)
   {
 	  //snd_ctl_close( ctl_handle );
-	  ctl_handle = 0;
+	  ctl_handle = nullptr;
   }
 
-  if ( _handle != 0 )
+  if (_handle!=nullptr)
   {
     //qCDebug(KMIX_LOG) << "IN  Mixer_ALSA::close()";
     snd_mixer_free ( _handle );
@@ -543,7 +546,7 @@ Mixer_ALSA::close()
 	if ( ret == 0 ) ret = ret2; // no error before => use current error code
     }
 
-    _handle = 0;
+    _handle = nullptr;
     //qCDebug(KMIX_LOG) << "OUT Mixer_ALSA::close()";
 
   }
@@ -563,25 +566,26 @@ Mixer_ALSA::close()
  * Resolve index to a control (snd_mixer_elem_t*)
  * @par idx Index to query. For any invalid index (including -1) returns a 0 control.
  */
-snd_mixer_elem_t* Mixer_ALSA::getMixerElem(int idx) {
-	snd_mixer_elem_t* elem = 0;
-        if ( ! m_isOpen ) return elem; // unplugging guard
+snd_mixer_elem_t* Mixer_ALSA::getMixerElem(int idx)
+{
+	snd_mixer_elem_t *elem = nullptr;
+        if (!m_isOpen) return (elem);			// unplugging guard
+	if (idx==-1) return (elem);
 
-	if ( idx == -1 ) {
-		return elem;
-	}
 	if ( int( mixer_sid_list.count() ) > idx ) {
 		snd_mixer_selem_id_t * sid = mixer_sid_list[ idx ];
 		// The next line (hopefully) only finds selem's, not elem's.
 		elem = snd_mixer_find_selem(_handle, sid);
 
-		if ( elem == 0 ) {
+		if (elem==nullptr)
+                {
 			// !! Check, whether the warning should be omitted. Probably
 			//    Route controls are non-simple elements.
 			qCDebug(KMIX_LOG) << "Error finding mixer element " << idx;
 		}
 	}
-	return elem;
+
+	return (elem);
 
 /*
  I would have liked to use the following trivial implementation instead of the
@@ -728,12 +732,13 @@ void Mixer_ALSA::setEnumIdHW(const QString& id, unsigned int idx) {
  *          of the SAME snd_mixer_elem_t. KMix does NOT support that and
  *          always shows the value of the first channel.
  */
-unsigned int Mixer_ALSA::enumIdHW(const QString& id) {
+unsigned int Mixer_ALSA::enumIdHW(const QString& id)
+{
     int devnum = id2num(id);
     snd_mixer_elem_t *elem = getMixerElem( devnum );
     unsigned int idx = 0;
 
-    if ( elem != 0 && snd_mixer_selem_is_enumerated(elem) )
+    if (elem!=nullptr && snd_mixer_selem_is_enumerated(elem) )
     {
         int ret = snd_mixer_selem_get_enum_item(elem,SND_MIXER_SCHN_FRONT_LEFT,&idx);
         if (ret < 0) {
@@ -773,7 +778,7 @@ Mixer_ALSA::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md )
     	}
     	else
     	{
-            for (const VolumeChannel &vc : qAsConst(volumePlayback.getVolumes()))
+            for (const VolumeChannel &vc : std::as_const(volumePlayback.getVolumes()))
         {
                int ret = 0;
                switch(vc.chid) {
@@ -809,7 +814,7 @@ Mixer_ALSA::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md )
     // --- capture volume
     if ( snd_mixer_selem_has_capture_volume ( elem ) )
     {
-        for (const VolumeChannel &vc : qAsConst(volumeCapture.getVolumes()))
+        for (const VolumeChannel &vc : std::as_const(volumeCapture.getVolumes()))
         {
                int ret = 0;
                switch(vc.chid) {
@@ -840,7 +845,7 @@ Mixer_ALSA::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md )
         // Refresh the capture switch information of *all* controls of this card.
         // Doing it for all is necessary, because enabling one record source often
         // automatically disables another record source (due to the hardware design)
-        for (const shared_ptr<MixDevice> &md : qAsConst(m_mixDevices))
+        for (const shared_ptr<MixDevice> &md : std::as_const(m_mixDevices))
         {
             bool isRecsrc =  isRecsrcHW( md->id() );
             // qCDebug(KMIX_LOG) << "Mixer::setRecordSource(): isRecsrcHW(" <<  md->id() << ") =" <<  isRecsrc;
@@ -850,7 +855,7 @@ Mixer_ALSA::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md )
     }
 
     // The state Mixer::OK_UNCHANGED is not implemented. It is not strictly required for
-    //  non-pollling backends. 
+    //  non-pollling backends.
     return Mixer::OK;
 }
 
@@ -889,7 +894,7 @@ Mixer_ALSA::writeVolumeToHW( const QString& id, shared_ptr<MixDevice> md )
     	}
     	else
     	{
-            for (const VolumeChannel &vc : qAsConst(volumePlayback.getVolumes()))
+            for (const VolumeChannel &vc : std::as_const(volumePlayback.getVolumes()))
       {
                int ret = 0;
                switch(vc.chid)
@@ -915,7 +920,7 @@ Mixer_ALSA::writeVolumeToHW( const QString& id, shared_ptr<MixDevice> md )
     // --- capture volume
     if ( snd_mixer_selem_has_capture_volume ( elem ) )
     {
-        for (const VolumeChannel &vc : qAsConst(volumeCapture.getVolumes()))
+        for (const VolumeChannel &vc : std::as_const(volumeCapture.getVolumes()))
       {
                int ret = 0;
                switch(vc.chid) {
@@ -990,9 +995,10 @@ int ALSA_acceptsHotplugId(const QString &id)
     // The "control" one of these is taken as the canonical form.  The "card" and
     // "control" numbers are assumed to be the same, but this is not checked.
 
-    QRegExp rx("/card(\\d+)/controlC(\\d+)$");		// match sound card control device
-    if (!id.contains(rx)) return (-1);			// UDI not recognised
-    return (rx.cap(2).toInt());				// assume conversion succeeds
+    const QRegularExpression rx("/card(\\d+)/controlC(\\d+)$");
+    const QRegularExpressionMatch match = rx.match(id);	// match sound card control device
+    if (!match.hasCaptured(2)) return (-1);		// UDI not recognised
+    return (match.captured(2).toInt());			// assume conversion succeeds
 }
 
 
