@@ -80,11 +80,7 @@ Q_SIGNALS:
    void dropped(DialogViewConfigurationWidget* list, int index, DialogViewConfigurationItem* item);
 
 protected:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QMimeData* mimeData(const QList<QListWidgetItem*> items) const override;
-#else
     QMimeData* mimeData(const QList<QListWidgetItem *> &items) const override;
-#endif
     bool dropMimeData(int index, const QMimeData * mimeData, Qt::DropAction action) override;
 
     Qt::DropActions supportedDropActions() const override
@@ -118,7 +114,7 @@ class DialogViewConfiguration : public DialogBase
 
  public Q_SLOTS:
     void apply();
- 
+
  private Q_SLOTS:
    void slotDropped(DialogViewConfigurationWidget *list, int index, DialogViewConfigurationItem *item);
 
@@ -126,7 +122,7 @@ class DialogViewConfiguration : public DialogBase
    void moveSelectionToInactiveList();
    void selectionChangedActive();
    void selectionChangedInactive();
-   
+
  private:
     //void dragEnterEvent(QDragEnterEvent *event);
     void prepareControls(QAbstractItemModel* model, bool isActiveView, const GUIProfile::ControlSet &oldCtlSet, GUIProfile::ControlSet &newCtlSet);
