@@ -94,7 +94,7 @@ ViewDockAreaPopup::ViewDockAreaPopup(QWidget* parent, const QString &id, ViewBas
 	//
 	// TODO: is this necessary?  As the comment says, initLayout() does a
 	// clearMixers() which clears the mixers that addMixer() adds here.
-	for (Mixer *mixer : qAsConst(MixerToolBox::mixers()))
+	for (Mixer *mixer : std::as_const(MixerToolBox::mixers()))
 	{
 		addMixer(mixer);
 	}
@@ -481,7 +481,7 @@ void ViewDockAreaPopup::constructionFinished()
 	mainWindowButton = new QPushButton(QIcon::fromTheme("show-mixer"), "" , this);
 	mainWindowButton->setObjectName(QLatin1String("MixerPanel"));
 	mainWindowButton->setToolTip(i18n("Show the full mixer window"));
-	connect(mainWindowButton, SIGNAL(clicked()), SLOT(showPanelSlot()));
+	connect(mainWindowButton, &QAbstractButton::clicked, this, &ViewDockAreaPopup::showPanelSlot);
 
 	configureViewButton = createConfigureViewButton();
 
